class Mp3Map
{
public:
	Mp3Map();
	Mp3Map(int fd);
	Mp3Map(const char *path);
	~Mp3Map();

	int offset_to_frame(unsigned long offset);
	unsigned long frame_to_offset(int frame);
	unsigned long sample_to_offset(unsigned long sample);

	int attach(int fd);
	int attach(const char *path);
	int basic_info(const char *path);

	int bitrate;
	int samplerate;
	int framesize;
	int samples;
	int frames;
protected:
	int grow();
	bool bad_protection;
	unsigned long *framemap;
	int framecount;
	int allocation_size;
	int seconds;
};
